<?php 
namespace Elementor;
if( !defined( 'ABSPATH' ) ) exit; // No access of directly access


class Premium_Counter_Widget extends Widget_Base {

	public function get_name() {
		return 'premium-counter';
	}

	public function get_title() {
		return esc_html__( 'Premium Counter', 'premium_elementor' );
	}

	public function get_icon() {
		return 'pa-pa-counter';
	}

	public function get_script_depends() {
		return [ 'countup.js' ];
	}

	public function get_categories() {
		return [ 'premium-elements' ];
	}

    // Adding the controls fields for the premium counter
	// This will controls the animation, colors and background, dimensions etc
	protected function _register_controls() {
		$this->start_controls_section('pct-global-settings',
			[
				'label'		=> esc_html__( 'Premium Counter', 'premium_elementor' )
			]
		);

		$this->add_control('pct_icon_image',
		  	[
		     	'label'			=> esc_html__( 'Icon or Image Upload', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::SELECT,
		     	'options'		=> [
		     		'icon'		=> esc_html__('Icon Select', 'premium_elementor'),
		     		'custom'	=> esc_html__( 'Your Custom Image', 'premium_elementor')
		     	],
		     	'default'		=> 'icon'
		  	]
		);

		$this->add_control('pct-icon',
		  	[
		     	'label'			=> esc_html__( 'Select Icon', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::ICON,
                        'default'               => 'fa fa-clock-o',
			  	'condition'			=> [
			  		'pct_icon_image' => 'icon'
			  	]
		  	]
		);

		$this->add_control('pct_image_upload',
		  	[
		     	'label'			=> esc_html__( 'Upload Image', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::MEDIA,
			  	'condition'			=> [
			  		'pct_icon_image' => 'custom'
			  	],
			  	'default'		=> [
			  		'url' => Utils::get_placeholder_image_src(),
			  	]
		  	]
		);

		$this->add_responsive_control('pct-icon-size',
		  	[
		     	'label'			=> esc_html__( 'Size of Icon', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::SLIDER,
		     	'default' => [
					'size' => 25,
				],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 200,
					]
				],
				'selectors' => [
					'{{WRAPPER}} .counter-area .counter-icon .icon' => 'font-size: {{SIZE}}{{UNIT}};'
				],
			  	'condition'     => [
			  		'pct_icon_image' => 'icon'
			  	]
		  	]
		);

		$this->add_responsive_control('pct_image_size',
		  	[
		     	'label'			=> esc_html__( 'Size of Image', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::SLIDER,
		     	'default' => [
					'size' => 60,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					]
				],
				'selectors' => [
					'{{WRAPPER}} .counter-area .counter-icon img.custom-image' => 'width: {{SIZE}}%;'
				],
			  	'condition'     => [
			  		'pct_icon_image' => 'custom'
			  	]
		  	]
		);

		$this->add_control('pct-icon-color',
		  	[
				'label'         => esc_html__( 'Icon Color', 'premium_elementor' ),
				'type' 			=> Controls_Manager::COLOR,
				'scheme' 		=> [
				    'type' 	=> Scheme_Color::get_type(),
				    'value' => Scheme_Color::COLOR_1,
				],
				'selectors'     => [
					'{{WRAPPER}} .counter-area .counter-icon .icon' => 'color: {{VALUE}};'
				],
			  	'condition'     => [
			  		'pct_icon_image' => 'icon'
			  	]
			]
		);

		$this->add_control('pct_icon_style',
		  	[
				'label' 		=> esc_html__( 'Icon Style', 'premium_elementor' ),
				'type' 			=> Controls_Manager::SELECT,
				'options'		=> [
					'simple'	=> esc_html__( 'Simple', 'premium_elementor' ),
					'circle'	=> esc_html__( 'Circle Background', 'premium_elementor' ),
					'square'	=> esc_html__( 'Square Background', 'premium_elementor' ),
					'design'	=> esc_html__( 'Your Design', 'premium_elementor' )
				],
				'default' 		=> 'simple'
			]
		);

		$this->add_control('pct_icon_bg',
			[
				'label' 		=> esc_html__( 'Background Color', 'premium_elementor' ),
				'type' 			=> Controls_Manager::COLOR,
				'scheme' 		=> [
				    'type' 	=> Scheme_Color::get_type(),
				    'value' => Scheme_Color::COLOR_1,
				],
				'condition'		=> [
					'pct_icon_style!' => 'simple'
				],
				'selectors' => [
					'{{WRAPPER}} .counter-area .counter-icon .icon-bg' => 'background: {{VALUE}};'
				]
			]
		);

		$this->add_responsive_control('pct_icon_bg_size',
		  	[
		     	'label'			=> esc_html__( 'Background size', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::SLIDER,
		     	'default' => [
					'size' => 150,
				],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 600,
					]
				],
				'condition'		=> [
					'pct_icon_style!' => 'simple'
				],
				'selectors' => [
					'{{WRAPPER}} .counter-area .counter-icon span.icon' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};'
				]
		  	]
		);

		$this->add_responsive_control('pct_icon_v_align',
		  	[
		     	'label'			=> esc_html__( 'Icon vertical Align', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::SLIDER,
		     	'default' => [
					'size' => 150,
				],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 600,
					]
				],
				'condition'		=> [
					'pct_icon_style!' => 'simple'
				],
				'selectors' => [
					'{{WRAPPER}} .counter-area .counter-icon span.icon' => 'line-height: {{SIZE}}{{UNIT}};'
				]
		  	]
		);

		$this->add_control('icon_border_style',
			[
				'label' 		=> esc_html__( 'Icon Border Style', 'premium_elementor' ),
				'type' 			=> Controls_Manager::SELECT,
				'options' 		=> [
					'none'			=> esc_html__('None', 'premium_elementor' ),
					'solid'			=> esc_html__('Solid', 'premium_elementor' ),
					'dashed'		=> esc_html__('Dashed', 'premium_elementor' ),
					'dotted'		=> esc_html__('Dotted', 'premium_elementor' ),
					'double'		=> esc_html__('Double', 'premium_elementor' ),
					'inset'			=> esc_html__('Inset', 'premium_elementor' ),
					'outset'		=> esc_html__('Outset', 'premium_elementor' ),
				],
				'default'		=> 'none',
				'condition'		=> [
					'pct_icon_style' => 'design'
				]
			]
		);

		$this->add_control('pct_icon_border_color',
			[
				'label' 		=> esc_html__( 'Border Color', 'premium_elementor' ),
				'type' 			=> Controls_Manager::COLOR,
				'scheme' 		=> [
				    'type' 	=> Scheme_Color::get_type(),
				    'value' => Scheme_Color::COLOR_1,
				],
				'condition'		=> [
					'icon_border_style!' => 'none',
					'pct_icon_style' => 'design'
				],
				'selectors'     => [
					'{{WRAPPER}} .counter-area .counter-icon .design' => 'border-color: {{VALUE}};'
				]
			]
		);

		$this->add_responsive_control('pct_icon_border_width',
		  	[
		     	'label'			=> esc_html__( 'Border Width', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::SLIDER,
		     	'default'       => [
					'size'  => 1,
				],
				'range'         => [
					'px'    => [
						'min' => 0,
						'max' => 20,
					]
				],
				'condition'		=> [
					'icon_border_style!' => 'none',
					'pct_icon_style' => 'design'
				],
				'selectors'     => [
					'{{WRAPPER}} .counter-area .counter-icon .design' => 'border-width: {{SIZE}}{{UNIT}};'
				]
		  	]
		);

		$this->add_responsive_control('pct_icon_border_radius',
		  	[
		     	'label'			=> esc_html__( 'Border Radius', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::SLIDER,
		     	'default'       => [
					'size' => 300,
				],
				'range'         => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					]
				],
				'condition'		=> [
					'icon_border_style!' => 'none',
					'pct_icon_style' => 'design'
				],
				'selectors'     => [
					'{{WRAPPER}} .counter-area .counter-icon .design' => 'border-radius: {{SIZE}}{{UNIT}};'
				]
		  	]
		);

		$this->add_control('pct_icon_animation',
			[
				'label'			=> esc_html__( 'Animations', 'premium_elementor' ),
				'type'			=> Controls_Manager::SELECT,
				'default'		=> 'no-animation',
				'options'		=> [
					'no-animation'		=> esc_html__( 'Default', 'premium_elementor' ),
					'swing'				=> esc_html__( 'Swing', 'premium_elementor' ),
					'pulse'				=> esc_html__( 'Pulse', 'premium_elementor' ),
					'fadeIn'			=> esc_html__( 'Fade In', 'premium_elementor' ),
					'fadeInUp'			=> esc_html__( 'Fade In Up', 'premium_elementor' ),
					'fadeInDown' 		=> esc_html__( 'Fade In Down', 'premium_elementor' ),
					'fadeInLeft' 		=> esc_html__( 'Fade In Left', 'premium_elementor' ),
					'fadeInRight' 		=> esc_html__( 'Fade In Right', 'premium_elementor' ),
					'fadeInUpBig' 		=> esc_html__( 'Fade In Up Long', 'premium_elementor' ),
					'fadeInDownBig' 	=> esc_html__( 'Fade In Down Long', 'premium_elementor' ),
					'fadeInLeftBig' 	=> esc_html__( 'Fade In Left Long', 'premium_elementor' ),
					'fadeInRightBig' 	=> esc_html__( 'Fade In Right Long', 'premium_elementor' ),
					'slideInUp' 		=> esc_html__( 'Slide In Up', 'premium_elementor' ),
					'slideInDown' 		=> esc_html__( 'Slide In Down', 'premium_elementor' ),
					'slideInLeft' 		=> esc_html__( 'Slide In Left', 'premium_elementor' ),
					'slideInRight' 		=> esc_html__( 'Slide In Right', 'premium_elementor' ),
					'bounceIn'			=> esc_html__( 'Bounce In', 'premium_elementor' ),
					'bounceInUp' 		=> esc_html__( 'Bounce In Up', 'premium_elementor' ),
					'bounceInDown' 		=> esc_html__( 'Bounce In Down', 'premium_elementor' ),
					'bounceInLeft' 		=> esc_html__( 'Bounce In Left', 'premium_elementor' ),
					'bounceInRight' 	=> esc_html__( 'Bounce In Right', 'premium_elementor' ),
					'rotateIn' 			=> esc_html__( 'Rotate In', 'premium_elementor' ),
					'lightSpeedIn' 		=> esc_html__( 'Light Speed In', 'premium_elementor' ),
					'rollIn' 			=> esc_html__( 'Roll In', 'premium_elementor' ),
				]
			]
		);

		$this->add_control('pct_icon_position',
			[
				'label'			=> esc_html__( 'Icon Position', 'premium_elementor' ),
				'type'			=> Controls_Manager::SELECT,
				'default'		=> 'no-animation',
				'options'		=> [
					'top'   => esc_html__( 'Top', 'premium_elementor' ),
					'right' => esc_html__( 'Right', 'premium_elementor' ),
					'left'  => esc_html__( 'Left', 'premium_elementor' ),
					
				],
				'default' 		=> 'top',
				'separator' 	=> 'after'
			]
		);


		$this->end_controls_section();

		$this->start_controls_section('pct_counter_setting',
			[
				'label'         => esc_html__( 'Counter Settings' , 'premium_elementor' )
			]
		);

		$this->add_control('pct_title',
			[
				'label'			=> esc_html__( 'Counter Title', 'premium_elementor' ),
				'type'			=> Controls_Manager::TEXT,
				'description'	=> esc_html__( 'Enter title for stats counter block', 'premium_elementor' )
			]
		);

		$this->add_control('pct_value',
			[
				'label'			=> esc_html__( 'Counter Value', 'premium_elementor' ),
				'type'			=> Controls_Manager::NUMBER,
				'description'	=> esc_html__( 'Enter Cunter Value', 'premium_elementor' ),
				'default'		=> 500
			]
		);

		$this->add_control('pct_t_separator',
			[
				'label'			=> esc_html__( 'Thousands Separator', 'premium_elementor' ),
				'type'			=> Controls_Manager::TEXT,
				'description'	=> esc_html__( 'Separate coverts 125000 into 125,000', 'premium_elementor' ),
				'default'		=> ','
			]
		);

		$this->add_control('pct_d_separator',
			[
				'label'			=> esc_html__( 'Replace Decimal Point With', 'premium_elementor' ),
				'type'			=> Controls_Manager::TEXT,
				'description'	=> esc_html__( 'Eg - 12.76, . will be replaced with value that you will enter above.', 'premium_elementor' ),
				'default'		=> '.'
			]
		);

		$this->add_control('pct_d_after',
			[
				'label'			=> esc_html__( 'Digits after decimal point', 'premium_elementor' ),
				'type'			=> Controls_Manager::NUMBER,
				'default'		=> 0
			]
		);

		$this->add_control('pct_preffix',
			[
				'label'			=> esc_html__( 'Counter Value Prefix', 'premium_elementor' ),
				'type'			=> Controls_Manager::TEXT,
				'description'	=> esc_html__( 'Enter prefix for counter value', 'premium_elementor' )
			]
		);

		$this->add_control('pct_suffix',
			[
				'label'			=> esc_html__( 'Counter Value suffix', 'premium_elementor' ),
				'type'			=> Controls_Manager::TEXT,
				'description'	=> esc_html__( 'Enter suffix for counter value', 'premium_elementor' )
			]
		);

		$this->add_control('pct_speed',
			[
				'label'			=> esc_html__( 'Counter rolling time', 'premium_elementor' ),
				'type'			=> Controls_Manager::NUMBER,
				'description'	=> esc_html__( 'How many seconds the counter should roll IN SECONDS?', 'premium_elementor' ),
				'default'		=> 3
			]
		);

		$this->end_controls_section();

		$this->start_controls_section('pct_typhography',
			[
				'label'         => esc_html__( 'Typhography Settings' , 'premium_elementor' ),
				'tab' 			=> Controls_Manager::TAB_STYLE
			]
		);

		$this->add_control('pct_title_color',
			[
				'label' 		=> esc_html__( 'Title Color', 'premium_elementor' ),
				'type' 			=> Controls_Manager::COLOR,
				'scheme' 		=> [
				    'type' 	=> Scheme_Color::get_type(),
				    'value' => Scheme_Color::COLOR_1,
				],
				'selectors'		=> [
					'{{WRAPPER}} .counter-area .counter-title' => 'color: {{VALUE}};'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'          => 'pct_title_typho',
				'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
				'selector'      => '{{WRAPPER}} .counter-area .counter-title',
				'separator'		=> 'after'
			]
		);

		$this->add_control('pct_value_color',
			[
				'label' 		=> esc_html__( 'Value Color', 'premium_elementor' ),
				'type' 			=> Controls_Manager::COLOR,
				'scheme' 		=> [
				    'type' 	=> Scheme_Color::get_type(),
				    'value' => Scheme_Color::COLOR_1,
				],
				'selectors'		=> [
					'{{WRAPPER}} .counter-area .counter-init' => 'color: {{VALUE}};'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'pct_value_typho',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .counter-area .counter-init',
				'separator'		=> 'after'
			]
		);

		$this->add_control('pct_suffix_prefix',
			[
				'label' 		=> esc_html__( 'Suffix-prefix Color', 'premium_elementor' ),
				'type' 			=> Controls_Manager::COLOR,
				'scheme' 		=> [
				    'type' 	=> Scheme_Color::get_type(),
				    'value' => Scheme_Color::COLOR_1,
				],
				'selectors' 	=> [
					'{{WRAPPER}} .counter-area span#suffix-prefix' => 'color: {{VALUE}}'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'pct_su_pre_typho',
				'scheme' 	=> Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .counter-area span#suffix-prefix'
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings();

		$options = ''; // The counter settings store
		$options .= 'useEasing : true,';

		if( $sep = $settings['pct_t_separator'] ) {
			$options .= 'separator : \''. $sep .'\',';
		}
		if( $dec = $settings['pct_d_separator'] ) {
			$options .= 'decimal : \''. $dec .'\',';
		}

		$prefix = !empty( $settings['pct_preffix'] ) ? '<span id="suffix-prefix" class="counter-su-pre"> '. $settings['pct_preffix'] .'</span>' : '';
		$suffix = !empty( $settings['pct_suffix'] ) ? '<span id="suffix-prefix" class="counter-su-pre">'. $settings['pct_suffix'] .' </span>' : '';
		$title 	= !empty( $settings['pct_title'] ) ? '<h2 class="counter-title">'. $settings['pct_title'] .'</h2>' : '';

		if( $settings['pct_icon_image'] == 'icon' ) {
			$icon_image = '<i class="' . $settings['pct-icon'] .'"></i>';
		} else {
			$icon_image = '<img class="custom-image" src="'.$settings['pct_image_upload']['url'] . '" alt="">';
		}

		$icon_style = $settings['pct_icon_style'] != 'simple' ? ' icon-bg ' . $settings['pct_icon_style'] : '';
		$border = $settings['icon_border_style'];
		$animation = $settings['pct_icon_animation'];

		$position = $settings['pct_icon_position'];
		$center		= $position == 'top' ? ' center' : '';
		$left = $position == 'left' ? ' left' : '';

		$counter_value 	= !empty( $settings['pct_value'] ) ? $settings['pct_value'] : 500;
		$speed 			= !empty( $settings['pct_speed'] ) ? $settings['pct_speed'] : 3;
		$d_after 		= !empty( $settings['pct_d_after'] ) ? intval( $settings['pct_d_after'] ) : 0;
 		$rand = rand( 100, 1000 );
 		$d_s = !empty( $settings['pct_d_separator'] ) ? $settings['pct_d_separator'] : '.';
 		$t_s = !empty( $settings['pct_t_separator'] ) ? $settings['pct_t_separator'] : ',';
 		$exact_value = number_format( $counter_value, $d_after, $d_s, $t_s );
 		$flex_width = '';
 		if( $settings['pct_icon_image'] == 'custom' && $settings['pct_icon_style'] == 'simple' ) {
 			$flex_width = ' flex-width ';
 		}
		?>

			<div class="counter-area<?php echo $center; ?>" id="counter-wrapper-<?php echo uniqid(); ?>">
				<?php if( $position == 'right' ) : ?>
					<div class="init-wrapper <?php echo $position; ?>">
						<?php echo $prefix; ?>
						<span class="counter-init" id="counter-<?php echo $rand; ?>"><?php echo $exact_value; ?></span>
						<?php echo $suffix; ?>
						<?php echo $title; ?>
					</div>

					<?php if( !empty( $settings['pct-icon'] ) || !empty( $settings['pct_image_upload'] ) ) : ?>
						<div class="counter-icon <?php echo $position; ?>">
							<span data-animation="<?php echo $animation; ?>" class="icon<?php echo $flex_width; ?><?php echo $icon_style; ?><?php echo ' ' . $border; ?>"><?php echo $icon_image; ?></span>
						</div>
					<?php endif; ?>

				<?php else: ?>

					<?php if( !empty( $settings['pct-icon'] ) || !empty( $settings['pct_image_upload'] ) ) : ?>
						<div class="counter-icon<?php echo $left; ?>">
							<span data-animation="<?php echo $animation; ?>" class="icon<?php echo $flex_width; ?><?php echo $icon_style; ?><?php echo ' ' . $border; ?>"><?php echo $icon_image; ?></span>
						</div>
					<?php endif; ?>

					<div class="init-wrapper<?php echo $left; ?>">
						<?php echo $prefix; ?>
						<span class="counter-init" id="counter-<?php echo $rand; ?>"><?php echo $exact_value; ?></span>
						<?php echo $suffix; ?>
						<?php echo $title; ?>
					</div>

				<?php endif; ?>
				
			</div>
			<script type="text/javascript">
				( function( $ ) {
					$(document).ready( function() {

						var counter = new CountUp(
							'counter-<?php echo $rand ; ?>', 0,
							<?php echo $counter_value; ?>,
							<?php echo $d_after; ?>,
							<?php echo $speed ; ?>, 
							{ <?php echo $options ?> }
						);

						if (!counter.error) {
						   	counter.start();
						} else {
						   	console.error(counter.error);
						}

						function isScrolledIntoView(elem) {
						    var docViewTop = $(window).scrollTop();
						    var docViewBottom = docViewTop + $(window).height();

						    var elemTop = elem.offset().top;
						    var elemBottom = elemTop + elem.height();

						    return ((elemBottom <= docViewBottom) && (elemTop >= docViewTop));
						}

						function addAnimation() {
							$('.counter-init').each( function() {
								var $this = $(this),
									parentId = $this.parents('.counter-area').attr('id'),
									iconClass = $('#' + parentId ).find('.icon'),
									animation = iconClass.data('animation');

								if( iconClass.length ) {
									if( isScrolledIntoView( iconClass ) ) {
										if( ! iconClass.hasClass('animated') ) {
											$('#' + parentId ).find('.icon').addClass('animated ' + animation );
										}
									}
								}
								
							});
						}
						addAnimation();
						$(window).on('scroll', function() {
							addAnimation();
						});
						
					});
				})( jQuery );
			</script>
		<?php
	}

}

Plugin::instance()->widgets_manager->register_widget_type( new Premium_Counter_Widget() );
