<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Premium_Title_Widget extends Widget_Base
{
    protected $templateInstance;

    public function getTemplateInstance() {
        return $this->templateInstance = premium_Template_Tags::getInstance();
    }

    public function get_name() {
        return 'premium-addon-title';
    }

    public function get_title() {
        return esc_html__('Premium Title', 'premium_elementor');
    }

    public function get_icon() {
        return 'pa-pa-text';
    }

    public function get_categories() {
        return [ 'premium-elements' ];
    }

    // Adding the controls fields for the premium title
    // This will controls the animation, colors and background, dimensions etc
    protected function _register_controls() {

        /* Start Title General Settings Section */
        $this->start_controls_section('premium_title_content',
                [
                    'label'         => esc_html__('General Settings', 'premium_elementor'),
                ]
                );
        
        /*Title Text*/ 
        $this->add_control('premium_title_text',
                [
                    'label'         => esc_html__('Title Content', 'premium_elementor'),
                    'type'          => Controls_Manager::TEXT,
                    'default'       => esc_html__('Premium Title','premium_elementor'),
                    'label_block'   => true,
                ]
                );

        /*Title HTML TAG*/ 
        $this->add_control('premium_title_tag',
                [
                    'label'         => esc_html__('Title HTML Tag', 'premium_elementor'),
                    'type'          => Controls_Manager::SELECT,
                    'default'       => esc_html__('h2','premium_elementor'),
                    'options'       => [
                        'h1'    => esc_html__('H1','premium_elementor'),
                        'h2'    => esc_html__('H2','premium_elementor'),
                        'h3'    => esc_html__('H3','premium_elementor'),
                        'h4'    => esc_html__('H4','premium_elementor'),
                        'h5'    => esc_html__('H5','premium_elementor'),
                        'h6'    => esc_html__('H6','premium_elementor'),
                        ],
                    ]
                );
        
        /*Title Align*/
        $this->add_responsive_control('premium_title_align',
                [
                    'label'         => esc_html__( 'Align', 'premium_elementor' ),
                    'type'          => Controls_Manager::CHOOSE,
                    'options'       => [
                        'left'      => [
                            'title'=> esc_html__( 'Left', 'premium_elementor' ),
                            'icon' => 'fa fa-align-left',
                            ],
                        'center'    => [
                            'title'=> esc_html__( 'Center', 'premium_elementor' ),
                            'icon' => 'fa fa-align-center',
                            ],
                        'right'     => [
                            'title'=> esc_html__( 'Right', 'premium_elementor' ),
                            'icon' => 'fa fa-align-right',
                            ],
                        ],
                    'default'       => 'left',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-container' => 'text-align: {{VALUE}};',
                        ],
                    ]
                );
        
        /*Icon*/
        $this->add_control('premium_title_icon', 
                [
                    'label'         => esc_html__('Icon', 'premium_elementor'),
                    'type'          => Controls_Manager::ICON,
                    'label_block'   => true,
                ]
                );
        
        /*Title Style*/
        $this->add_control('premium_title_style', 
                [
                    'label'         => esc_html__('Title Style', 'premium_elementor'),
                    'type'          => Controls_Manager::SELECT,
                    'default'       => 'style1',
                    'options'       => [
                        'style1'        => esc_html('Style1'),
                        'style2'        => esc_html('Style2'),
                        'style3'        => esc_html('Style3'),
                        'style4'        => esc_html('Style4'),
                        'style5'        => esc_html('Style5'),
                        'style6'        => esc_html('Style6'),
                        'style7'        => esc_html('Style7'),
                        ],
                    'label_block'   => true,
                    ]
                );
        
        /*Style 1*/
        /*Style 1 Border*/
        $this->add_group_control(
            Group_Control_Border::get_type(),
                [
                    'name'          => 'style_two_border',
                    'selector'      => '{{WRAPPER}} .premium-title-style1',
                    'condition'     => [
                        'premium_title_style'   => 'style1',
                        ],
                ]
                );
        
        /*Style 2*/
        /*Background Color*/
        $this->add_control('premium_title_style2_background_color', 
                [
                    'label'         => esc_html__('Background Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#e2e2e2',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-style2' => 'background-color: {{VALUE}};',
                        ],
                    'condition'     => [
                        'premium_title_style'   => 'style2',
                        ],
                    ]
                );
        
        /*Style 2*/
        /*Line Color*/
        $this->add_control('premium_title_style2_line_color', 
                [
                    'label'         => esc_html__('Line Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#6ec1e4',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-container' => 'border-bottom: 2px solid {{VALUE}};',
                        ],
                    'condition'     => [
                        'premium_title_style'   => 'style2',
                        ],
                    ]
                );
        
        /*Style 3*/
        /*Background Color*/
        $this->add_control('premium_title_style3_background_color', 
                [
                    'label'         => esc_html__('Background Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#e2e2e2',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-style3' => 'background-color: {{VALUE}};',
                        ],
                    'condition'     => [
                        'premium_title_style'   => 'style3',
                        ],
                    ]
                );
        
        /*Style 4*/
        /*Line Color*/
        $this->add_control('premium_title_style4_line_color', 
                [
                    'label'         => esc_html__('Line Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#6ec1e4',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-container' => 'border-bottom: 2px solid {{VALUE}};',
                        ],
                    'condition'     => [
                        'premium_title_style'   => 'style4',
                        ],
                    ]
                );
        
        /*Style 5*/
        /*Header Line Color*/
        $this->add_control('premium_title_style5_header_line_color', 
                [
                    'label'         => esc_html__('Header Line Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#6ec1e4',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-style5' => 'border-bottom: 2px solid {{VALUE}};',
                        ],
                    'condition'     => [
                        'premium_title_style'   => 'style5',
                        ],
                    ]
                );
       
        /*Container Line Color*/
        $this->add_control('premium_title_style5_container_line_color', 
                [
                    'label'         => esc_html__('Container Line Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#6ec1e4',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-container' => 'border-bottom: 2px solid {{VALUE}};',
                        ],
                    'condition'     => [
                        'premium_title_style'   => 'style5',
                        ],
                    ]
                );
        
        /*Style 7*/
        /*Header Line Color*/
        $this->add_control('premium_title_style6_header_line_color', 
                [
                    'label'         => esc_html__('Header Line Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#6ec1e4',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-style6' => 'border-bottom: 2px solid {{VALUE}};',
                        ],
                    'condition'     => [
                        'premium_title_style'   => 'style6',
                        ],
                    ]
                );
       
        /*Container Line Color*/
        $this->add_control('premium_title_style6_container_line_color', 
                [
                    'label'         => esc_html__('Container Line Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#6ec1e4',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-container' => 'border-bottom: 2px solid {{VALUE}};',
                        ],
                    'condition'     => [
                        'premium_title_style'   => 'style6',
                        ],
                    ]
                );
        
        /*Triangle Color*/
        $this->add_control('premium_title_style6_triangle_color', 
                [
                    'label'         => esc_html__('Triangle Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#6ec1e4',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-style6:before' => 'border-bottom-color: {{VALUE}};',
                        ],
                    'condition'     => [
                        'premium_title_style'   => 'style6',
                        ],
                    ]
                );
        
        /*Style 8*/
        /*Strip Width*/
        $this->add_control('premium_title_style7_strip_width',
                [
                    'label'         => esc_html__('Strip Width (PX)', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'default'       => [
                        'unit'  => 'px',
                        'size'  => '120',
                    ],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-style7-strip:before' => 'width: {{SIZE}}{{UNIT}};',
                    ],
                    'label_block'   => true,
                    'condition'     => [
                        'premium_title_style'   => 'style7',
                    ],
                ]
                );
        
        /*Strip Height*/
        $this->add_control('premium_title_style7_strip_height',
                [
                    'label'         => esc_html__('Strip Height (PX)', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', 'em'],
                    'default'       => [
                        'unit'  => 'px',
                        'size'  => '5',
                    ],
                    'label_block'   => true,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-style7-strip,{{WRAPPER}} .premium-title-style7-strip:before ' => 'height: {{SIZE}}{{UNIT}};',
                    ],
                    'condition'     => [
                        'premium_title_style'   => 'style7',
                    ],
                ]
                );
        
        /*Strip Top Spacing*/
        $this->add_control('premium_title_style7_strip_top_spacing',
                [
                    'label'         => esc_html__('Strip Top Spacing (PX)', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-style7-strip' => 'margin-top: {{SIZE}}{{UNIT}};',
                    ],
                    'label_block'   => true,
                    'condition'     => [
                        'premium_title_style'   => 'style7',
                    ],
                ]
                );
        
        /*Strip Bottom Spacing*/
        $this->add_control('premium_title_style7_strip_bottom_spacing',
                [
                    'label'         => esc_html__('Strip Bottom Spacing (PX)', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'label_block'   => true,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-style7-strip' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    ],
                    'condition'     => [
                        'premium_title_style'   => 'style7',
                    ],
                ]
                );
        
        /*Strip Color*/
        $this->add_control('premium_title_style7_strip_color', 
                [
                    'label'         => esc_html__('Strip Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#6ec1e4',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-style7-strip:before' => 'background-color: {{VALUE}};',
                        ],
                    'condition'     => [
                        'premium_title_style'   => 'style7',
                        ],
                    ]
                );
        
        /*Title Align*/
        $this->add_responsive_control('premium_title_style7_strip_align',
                [
                    'label'         => esc_html__( 'Align', 'elementor' ),
                    'type'          => Controls_Manager::CHOOSE,
                    'options'       => [
                        'left'      => [
                            'title'=> esc_html__( 'Left', 'elementor' ),
                            'icon' => 'fa fa-align-left',
                            ],
                        'none'    => [
                            'title'=> esc_html__( 'Center', 'elementor' ),
                            'icon' => 'fa fa-align-center',
                            ],
                        'right'     => [
                            'title'=> esc_html__( 'Right', 'elementor' ),
                            'icon' => 'fa fa-align-right',
                            ],
                        ],  
                    'default'       => 'none',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-style7-strip:before' => 'float: {{VALUE}};',
                        ],
                    'condition'     => [
                        'premium_title_style'   => 'style7',
                    ],
                    ]
                );
        
        /*End Title General Settings Section*/
        $this->end_controls_section();

        /*Start Styling Section*/
        $this->start_controls_section('premium_title_style_section',
                [
                    'label'         => esc_html__('Title Style', 'premium_elementor'),
                    'tab'           => Controls_Manager::TAB_STYLE,
                ]
            );
        
        /*Title Color*/
        $this->add_control('premium_title_color', 
                [
                    'label'         => esc_html__('Title Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
    				'scheme' => [
					    'type'  => Scheme_Color::get_type(),
					    'value' => Scheme_Color::COLOR_1,
					    ],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-header' => 'color: {{VALUE}};',
                        ],
                    ]
                );
        
        /*Title Typography*/
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'          => 'title_typography',
                    'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
                    'selector'      => '{{WRAPPER}} .premium-title-header',
                ]
                );
        
        /*Margin Top*/ 
        $this->add_control('premium_title_margin_top',
                [
                    'label'         => esc_html__('Margin Top', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'label_block'   => true,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-header' => 'margin-top: {{SIZE}}{{UNIT}};',   
                    ]
                ]
                );
        
        /*Margin Bottom*/ 
        $this->add_control('premium_title_margin_bottom',
                [
                    'label'         => esc_html__('Margin Bottom', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'label_block'   => true,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-header' => 'margin-bottom: {{SIZE}}{{UNIT}};',   
                    ]
                ]
                );
        
        /*Title Padding*/
        $this->add_control('premium_title_padding', 
                [
                    'label'         => esc_html__('Padding', 'premium_elementor'),
                    'type'          => Controls_Manager::DIMENSIONS,
                    'size_units'    => ['px', 'em', '%'],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-title-header' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
                    ]
                );

        /*End Progress Bar Section*/
        $this->end_controls_section();

    }

    protected function render($instance = [])
    {
        // get our input from the widget settings.
        $settings = $this->get_settings();
        
        $title_tag = $settings['premium_title_tag'];
        
        $selected_style = $settings['premium_title_style'];
?>

<div class="premium-title-container">
    <<?php echo $title_tag ; ?> class="premium-title-header premium-title-<?php echo $selected_style; ?>">
        <?php if ( $settings['premium_title_style'] === 'style7' ) : ?>
        <span class="premium-title-style7-strip"></span>
        <?php endif; ?>
        <?php if( !empty( $settings['premium_title_icon'] ) ) : ?>
        <i class="premium-title-icon <?php echo $settings['premium_title_icon'];?>"></i>
        <?php endif; ?>
        <?php echo $settings['premium_title_text']; ?>
    </<?php echo $title_tag; ?>>
</div>

    <?php
    }
}
Plugin::instance()->widgets_manager->register_widget_type(new Premium_Title_Widget());
